Struct google_container1::AddonsConfig[][src]

pub struct AddonsConfig {
    pub http_load_balancing: Option<HttpLoadBalancing>,
    pub network_policy_config: Option<NetworkPolicyConfig>,
    pub kubernetes_dashboard: Option<KubernetesDashboard>,
    pub horizontal_pod_autoscaling: Option<HorizontalPodAutoscaling>,
}

Configuration for the addons that can be automatically spun up in the cluster, enabling additional functionality.

This type is not used in any activity, and only used as part of another schema.

Fields

Configuration for the HTTP (L7) load balancing controller addon, which makes it easy to set up HTTP load balancers for services in a cluster.

Configuration for NetworkPolicy. This only tracks whether the addon is enabled or not on the Master, it does not track whether network policy is enabled for the nodes.

Configuration for the Kubernetes Dashboard.

Configuration for the horizontal pod autoscaling feature, which increases or decreases the number of replica pods a replication controller has based on the resource usage of the existing pods.