Struct google_container1::CreateClusterRequest [−][src]
pub struct CreateClusterRequest {
pub project_id: Option<String>,
pub zone: Option<String>,
pub parent: Option<String>,
pub cluster: Option<Cluster>,
}CreateClusterRequest creates a cluster.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- locations clusters create projects (request)
- zones clusters create projects (request)
Fields
project_id: Option<String>
Deprecated. The Google Developers Console project ID or project number. This field has been deprecated and replaced by the parent field.
zone: Option<String>
Deprecated. The name of the Google Compute Engine zone in which the cluster resides. This field has been deprecated and replaced by the parent field.
parent: Option<String>
The parent (project and location) where the cluster will be created. Specified in the format 'projects//locations/'.
cluster: Option<Cluster>