Struct google_container1::CreateNodePoolRequest [−][src]
CreateNodePoolRequest creates a node pool for a cluster.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
Fields
node_pool: Option<NodePool>
The node pool to create.