Struct google_container1::HttpLoadBalancing [−][src]
Configuration options for the HTTP (L7) load balancing controller addon, which makes it easy to set up HTTP load balancers for services in a cluster.
This type is not used in any activity, and only used as part of another schema.
Fields
disabled: Option<bool>
Whether the HTTP Load Balancing controller is enabled in the cluster. When enabled, it runs a small pod in the cluster that manages the load balancers.