Struct google_container1::ListNodePoolsResponse [−][src]
ListNodePoolsResponse is the result of ListNodePoolsRequest.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- zones clusters node pools list projects (response)
- locations clusters node pools list projects (response)
Fields
node_pools: Option<Vec<NodePool>>
A list of node pools for a cluster.