Struct google_container1::NetworkPolicyConfig[][src]

pub struct NetworkPolicyConfig {
    pub disabled: Option<bool>,
}

Configuration for NetworkPolicy. This only tracks whether the addon is enabled or not on the Master, it does not track whether network policy is enabled for the nodes.

This type is not used in any activity, and only used as part of another schema.

Fields

Whether NetworkPolicy is enabled for this cluster.