Struct google_container1::RollbackNodePoolUpgradeRequest [−][src]
pub struct RollbackNodePoolUpgradeRequest { /* fields omitted */ }RollbackNodePoolUpgradeRequest rollbacks the previously Aborted or Failed NodePool upgrade. This will be an no-op if the last upgrade successfully completed.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).