Struct google_container1::ServerConfig [−][src]
pub struct ServerConfig {
pub default_cluster_version: Option<String>,
pub valid_node_versions: Option<Vec<String>>,
pub valid_image_types: Option<Vec<String>>,
pub valid_master_versions: Option<Vec<String>>,
pub default_image_type: Option<String>,
}Kubernetes Engine service configuration.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- locations get server config projects (response)
- zones get serverconfig projects (response)
Fields
default_cluster_version: Option<String>
Version of Kubernetes the service deploys by default.
valid_node_versions: Option<Vec<String>>
List of valid node upgrade target versions.
valid_image_types: Option<Vec<String>>
List of valid image types.
valid_master_versions: Option<Vec<String>>
List of valid master versions.
default_image_type: Option<String>
Default image type.