Struct google_container1::SetLoggingServiceRequest[][src]

pub struct SetLoggingServiceRequest {
    pub logging_service: Option<String>,
}

SetLoggingServiceRequest sets the logging service of a cluster.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

The logging service the cluster should use to write metrics. Currently available options:

  • "logging.googleapis.com" - the Google Cloud Logging service
  • "none" - no metrics will be exported from the cluster