Struct google_container1::SetMasterAuthRequest [−][src]
pub struct SetMasterAuthRequest {
pub action: Option<String>,
pub update: Option<MasterAuth>,
}SetMasterAuthRequest updates the admin password of a cluster.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- zones clusters set master auth projects (request)
Fields
action: Option<String>
The exact form of action to be taken on the master auth.
update: Option<MasterAuth>
A description of the update.