Struct google_container1::SetNetworkPolicyRequest[][src]

pub struct SetNetworkPolicyRequest {
    pub network_policy: Option<NetworkPolicy>,
}

SetNetworkPolicyRequest enables/disables network policy for a cluster.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

Configuration options for the NetworkPolicy feature.