Struct google_container1::SetNodePoolAutoscalingRequest[][src]

pub struct SetNodePoolAutoscalingRequest {
    pub autoscaling: Option<NodePoolAutoscaling>,
}

SetNodePoolAutoscalingRequest sets the autoscaler settings of a node pool.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

Autoscaling configuration for the node pool.