[][src]Struct google_container1::SetNodePoolSizeRequest

pub struct SetNodePoolSizeRequest {
    pub name: Option<String>,
    pub zone: Option<String>,
    pub node_count: Option<i32>,
    pub project_id: Option<String>,
    pub cluster_id: Option<String>,
    pub node_pool_id: Option<String>,
}

SetNodePoolSizeRequest sets the size a node pool.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

name: Option<String>

The name (project, location, cluster, node pool id) of the node pool to set size. Specified in the format 'projects//locations//clusters//nodePools/'.

zone: Option<String>

Deprecated. The name of the Google Compute Engine zone in which the cluster resides. This field has been deprecated and replaced by the name field.

node_count: Option<i32>

The desired node count for the pool.

project_id: Option<String>

Deprecated. The Google Developers Console project ID or project number. This field has been deprecated and replaced by the name field.

cluster_id: Option<String>

Deprecated. The name of the cluster to update. This field has been deprecated and replaced by the name field.

node_pool_id: Option<String>

Deprecated. The name of the node pool to update. This field has been deprecated and replaced by the name field.