Struct google_container1::UpdateNodePoolRequest[][src]

pub struct UpdateNodePoolRequest {
    pub name: Option<String>,
    pub zone: Option<String>,
    pub project_id: Option<String>,
    pub node_version: Option<String>,
    pub cluster_id: Option<String>,
    pub image_type: Option<String>,
    pub node_pool_id: Option<String>,
}

UpdateNodePoolRequests update a node pool's image and/or version.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

The name (project, location, cluster, node pool) of the node pool to update. Specified in the format 'projects//locations//clusters//nodePools/'.

Deprecated. The name of the Google Compute Engine zone in which the cluster resides. This field has been deprecated and replaced by the name field.

Deprecated. The Google Developers Console project ID or project number. This field has been deprecated and replaced by the name field.

The Kubernetes version to change the nodes to (typically an upgrade).

Users may specify either explicit versions offered by Kubernetes Engine or version aliases, which have the following behavior:

  • "latest": picks the highest valid Kubernetes version
  • "1.X": picks the highest valid patch+gke.N patch in the 1.X version
  • "1.X.Y": picks the highest valid gke.N patch in the 1.X.Y version
  • "1.X.Y-gke.N": picks an explicit Kubernetes version
  • "-": picks the Kubernetes master version

Deprecated. The name of the cluster to upgrade. This field has been deprecated and replaced by the name field.

The desired image type for the node pool.

Deprecated. The name of the node pool to upgrade. This field has been deprecated and replaced by the name field.