Struct google_container1::CreateClusterRequest [−][src]
CreateClusterRequest creates a cluster.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- zones clusters create projects (request)
Fields
cluster: Option<Cluster>