Struct google_container1::NodePoolAutoscaling [−][src]
pub struct NodePoolAutoscaling {
pub min_node_count: Option<i32>,
pub enabled: Option<bool>,
pub max_node_count: Option<i32>,
}NodePoolAutoscaling contains information required by cluster autoscaler to adjust the size of the node pool to the current cluster usage.
This type is not used in any activity, and only used as part of another schema.
Fields
min_node_count: Option<i32>
Minimum number of nodes in the NodePool. Must be >= 1 and <= max_node_count.
enabled: Option<bool>
Is autoscaling enabled for this node pool.
max_node_count: Option<i32>
Maximum number of nodes in the NodePool. Must be >= min_node_count. There has to enough quota to scale up the cluster.