Struct google_container1::RollbackNodePoolUpgradeRequest [−][src]
pub struct RollbackNodePoolUpgradeRequest {
pub project_id: Option<String>,
pub cluster_id: Option<String>,
pub name: Option<String>,
pub zone: Option<String>,
pub node_pool_id: Option<String>,
}RollbackNodePoolUpgradeRequest rollbacks the previously Aborted or Failed NodePool upgrade. This will be an no-op if the last upgrade successfully completed.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
Fields
project_id: Option<String>
Deprecated. The Google Developers Console project ID or project number. This field has been deprecated and replaced by the name field.
cluster_id: Option<String>
Deprecated. The name of the cluster to rollback. This field has been deprecated and replaced by the name field.
name: Option<String>
The name (project, location, cluster, node pool id) of the node poll to rollback upgrade. Specified in the format 'projects//locations//clusters//nodePools/'.
zone: Option<String>
Deprecated. The name of the Google Compute Engine zone in which the cluster resides. This field has been deprecated and replaced by the name field.
node_pool_id: Option<String>
Deprecated. The name of the node pool to rollback. This field has been deprecated and replaced by the name field.