Struct google_container1::SetLoggingServiceRequest [−][src]
SetLoggingServiceRequest sets the logging service of a cluster.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- zones clusters logging projects (request)
Fields
logging_service: Option<String>
The logging service the cluster should use to write metrics. Currently available options:
- "logging.googleapis.com" - the Google Cloud Logging service
- "none" - no metrics will be exported from the cluster