Struct google_container1::SetLoggingServiceRequest [−][src]
pub struct SetLoggingServiceRequest {
pub project_id: Option<String>,
pub logging_service: Option<String>,
pub cluster_id: Option<String>,
pub name: Option<String>,
pub zone: Option<String>,
}SetLoggingServiceRequest sets the logging service of a cluster.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- locations clusters set logging projects (request)
- zones clusters logging projects (request)
Fields
project_id: Option<String>
Deprecated. The Google Developers Console project ID or project number. This field has been deprecated and replaced by the name field.
logging_service: Option<String>
The logging service the cluster should use to write metrics. Currently available options:
- "logging.googleapis.com" - the Google Cloud Logging service
- "none" - no metrics will be exported from the cluster
cluster_id: Option<String>
Deprecated. The name of the cluster to upgrade. This field has been deprecated and replaced by the name field.
name: Option<String>
The name (project, location, cluster) of the cluster to set logging. Specified in the format 'projects//locations//clusters/*'.
zone: Option<String>
Deprecated. The name of the Google Compute Engine zone in which the cluster resides. This field has been deprecated and replaced by the name field.