Struct google_container1::SetMaintenancePolicyRequest [−][src]
pub struct SetMaintenancePolicyRequest {
pub project_id: Option<String>,
pub maintenance_policy: Option<MaintenancePolicy>,
pub cluster_id: Option<String>,
pub name: Option<String>,
pub zone: Option<String>,
}SetMaintenancePolicyRequest sets the maintenance policy for a cluster.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
Fields
project_id: Option<String>
The Google Developers Console project ID or project number.
maintenance_policy: Option<MaintenancePolicy>
The maintenance policy to be set for the cluster. An empty field clears the existing maintenance policy.
cluster_id: Option<String>
The name of the cluster to update.
name: Option<String>
The name (project, location, cluster id) of the cluster to set maintenance policy. Specified in the format 'projects//locations//clusters/*'.
zone: Option<String>
The name of the Google Compute Engine zone in which the cluster resides.