Struct google_container1::SetNodePoolAutoscalingRequest [−][src]
pub struct SetNodePoolAutoscalingRequest {
pub name: Option<String>,
pub zone: Option<String>,
pub project_id: Option<String>,
pub autoscaling: Option<NodePoolAutoscaling>,
pub cluster_id: Option<String>,
pub node_pool_id: Option<String>,
}SetNodePoolAutoscalingRequest sets the autoscaler settings of a node pool.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
Fields
name: Option<String>
The name (project, location, cluster, node pool) of the node pool to set autoscaler settings. Specified in the format 'projects//locations//clusters//nodePools/'.
zone: Option<String>
Deprecated. The name of the Google Compute Engine zone in which the cluster resides. This field has been deprecated and replaced by the name field.
project_id: Option<String>
Deprecated. The Google Developers Console project ID or project number. This field has been deprecated and replaced by the name field.
autoscaling: Option<NodePoolAutoscaling>
Autoscaling configuration for the node pool.
cluster_id: Option<String>
Deprecated. The name of the cluster to upgrade. This field has been deprecated and replaced by the name field.
node_pool_id: Option<String>
Deprecated. The name of the node pool to upgrade. This field has been deprecated and replaced by the name field.