Struct google_container1::SetNodePoolSizeRequest[][src]

pub struct SetNodePoolSizeRequest {
    pub node_count: Option<i32>,
}

SetNodePoolSizeRequest sets the size a node pool.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

The desired node count for the pool.