Struct google_container1::SetNodePoolSizeRequest [−][src]
SetNodePoolSizeRequest sets the size a node pool.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
Fields
node_count: Option<i32>
The desired node count for the pool.